package com.chelvc.framework.base.crypto;

import java.util.Objects;
import javax.crypto.Cipher;

import com.chelvc.framework.common.util.CodecUtils;

/**
 * 加解密处理抽象实现
 *
 * @author Woody
 * @date 2025/1/14
 */
public abstract class AbstractCipherHandler implements CipherHandler {
    /**
     * 获取加密处理器
     *
     * @return 密码处理器实例
     */
    public abstract Cipher getEncryptor();

    /**
     * 获取解密处理器
     *
     * @return 密码处理器实例
     */
    public abstract Cipher getDecrypter();

    @Override
    public byte[] encrypt(byte[] bytes) {
        Cipher encryptor = Objects.requireNonNull(this.getEncryptor());
        return CodecUtils.codec(encryptor, bytes);
    }

    @Override
    public byte[] decrypt(byte[] bytes) {
        Cipher decrypter = Objects.requireNonNull(this.getDecrypter());
        return CodecUtils.codec(decrypter, bytes);
    }
}
